summaryrefslogtreecommitdiffstats
path: root/macosx/tkMacOSXNotify.c
diff options
context:
space:
mode:
authorculler <culler>2020-05-16 17:56:24 (GMT)
committerculler <culler>2020-05-16 17:56:24 (GMT)
commit5b8151f29ca6b12d3421c026eae1a994e702f7b5 (patch)
treee838e2463d61a0ae09e2bd13df04b1b54cf575e5 /macosx/tkMacOSXNotify.c
parentdc8dcbced6e03edb40b76e2108e6a4ecf6ff37fd (diff)
downloadtk-5b8151f29ca6b12d3421c026eae1a994e702f7b5.zip
tk-5b8151f29ca6b12d3421c026eae1a994e702f7b5.tar.gz
tk-5b8151f29ca6b12d3421c026eae1a994e702f7b5.tar.bz2
Fix compiler errors and warnings on macOS 10.6 (Snow Leopard)
Diffstat (limited to 'macosx/tkMacOSXNotify.c')
-rw-r--r--macosx/tkMacOSXNotify.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/macosx/tkMacOSXNotify.c b/macosx/tkMacOSXNotify.c
index 77e9e74..96c9a7a 100644
--- a/macosx/tkMacOSXNotify.c
+++ b/macosx/tkMacOSXNotify.c
@@ -145,18 +145,18 @@ void DebugPrintQueue(void)
/*
* Workaround for an Apple bug. When an accented character is selected
* from an NSTextInputClient popup character viewer with the mouse, Apple
* sends an event of type NSEventTypeAppKitDefined and subtype 21. If that
* event is sent up the responder chain it causes Apple to print a warning
* to the console log and, extremely obnoxiously, also to stderr, which
* says "Window move completed without beginning." Apparently they are
* sending the "move completed" event without having sent the "move began"
* event of subtype 20, and then announcing their error on our stderr.
* Also, of course, no movement is occurring. The popup is not movable and
* is just being closed. The bug has been reported to Apple. If they ever
* fix it, this block should be removed.
*/
- if ([theEvent type] == NSEventTypeAppKitDefined) {
+ if ([theEvent type] == NSAppKitDefined) {
static Bool aWindowIsMoving = NO;
switch([theEvent subtype]) {
case 20:
@@ -145,18 +145,18 @@ void DebugPrintQueue(void)
* Workaround for an Apple bug. When an accented character is selected
* from an NSTextInputClient popup character viewer with the mouse, Apple
- * sends an event of type NSEventTypeAppKitDefined and subtype 21. If that
- * event is sent up the responder chain it causes Apple to print a warning
- * to the console log and, extremely obnoxiously, also to stderr, which
- * says "Window move completed without beginning." Apparently they are
- * sending the "move completed" event without having sent the "move began"
- * event of subtype 20, and then announcing their error on our stderr.
- * Also, of course, no movement is occurring. The popup is not movable and
- * is just being closed. The bug has been reported to Apple. If they ever
- * fix it, this block should be removed.
+ * sends an event of type NSAppKitDefined and subtype 21. If that event is
+ * sent up the responder chain it causes Apple to print a warning to the
+ * console log and, extremely obnoxiously, also to stderr, which says
+ * "Window move completed without beginning." Apparently they are sending
+ * the "move completed" event without having sent the "move began" event of
+ * subtype 20, and then announcing their error on our stderr. Also, of
+ * course, no movement is occurring. The popup is not movable and is just
+ * being closed. The bug has been reported to Apple. If they ever fix it,
+ * this block should be removed.
*/